@@ -1,6 +1,6 @@
 use crate::{Cwt, CwtParseError, DgcCertContainer, EcAlg, TrustList};
 use ring_compat::signature::{ecdsa::p256::Signature, Verifier};
-use std::convert::TryInto;
+use std::{convert::TryInto, fmt::Display};
 use thiserror::Error;
 
 #[derive(Error, Debug)]
@@ -28,6 +28,40 @@ pub enum SignatureValidity {
     KeyNotInTrustList(Vec<u8>),
 }
 
+impl Display for SignatureValidity {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        use SignatureValidity::*;
+        match self {
+            Valid => write!(f, "Valid Signature"),
+            Invalid => write!(f, "Invalid Signature"),
+            MissingKid => write!(f, "The certificate did not specify a Key Id (kid)"),
+            MissingSigningAlgorithm => {
+                write!(
+                    f,
+                    "The certificate did not specify a signing algorithm (alg)"
+                )
+            }
+            SignatureMalformed => {
+                write!(f, "The signature bytes are malformed")
+            }
+            UnsupportedSigningAlgorithm(alg) => {
+                write!(
+                    f,
+                    "The signature algorithm '{}' is not supported by this library",
+                    alg
+                )
+            }
+            KeyNotInTrustList(kid) => {
+                write!(
+                    f,
+                    "The public key '{}' was not found in the given trustlist",
+                    base64::encode(kid)
+                )
+            }
+        }
+    }
+}
+
 impl SignatureValidity {
     pub fn is_valid(&self) -> bool {
         matches!(self, SignatureValidity::Valid)
@@ -41,8 +75,8 @@ fn remove_prefix(data: &'_ str) -> Result<&'_ str, ParseError> {
     }
 
     // check HC1: header
-    if &data[0..4] != "HC1:" {
-        return Err(ParseError::InvalidPrefix(String::from(&data[0..3])));
+    if !data.starts_with("HC1:") {
+        return Err(ParseError::InvalidPrefix(data.chars().take(4).collect()));
     }
 
     Ok(&data[4..])
